import { Keys, isNil, useEventCallback } from "../../shared";
export function useOverlayTrigger(isOpen, {
  hideOnLeave,
  trigger = "click",
  onShow,
  onHide,
  isDisabled
} = {}) {
  const toggle = event => {
    if (isOpen) {
      hide(event);
    } else {
      show(event);
    }
  };

  const show = event => {
    if (!isNil(onShow)) {
      onShow(event);
    }
  };

  const hide = event => {
    if (!isNil(onHide)) {
      onHide(event);
    }
  };

  const handleClick = useEventCallback(event => {
    event.preventDefault();
    toggle(event);
  });
  const handleKeyDown = useEventCallback(event => {
    switch (event.key) {
      case Keys.enter:
      case Keys.space:
        event.preventDefault();
        show(event);
        break;
    }
  }); // Hotfix for https://bugzilla.mozilla.org/show_bug.cgi?id=1487102

  const handleKeyUp = useEventCallback(event => {
    if (event.key === Keys.space) {
      event.preventDefault();
    }
  });
  const handleMouseEnter = useEventCallback(event => {
    show(event);
  });
  const handleMouseLeave = useEventCallback(event => {
    hide(event);
  });
  const handleFocus = useEventCallback(event => {
    show(event);
  });
  const handleBlur = useEventCallback(event => {
    hide(event);
  });

  if (isDisabled) {
    return {};
  }

  switch (trigger) {
    case "click":
      // The overlay will show on click or on "Enter" or "Space" keydown.
      return {
        onClick: handleClick,
        onKeyDown: !isOpen ? handleKeyDown : undefined,
        onKeyUp: !isOpen ? handleKeyUp : undefined
      };

    case "hover":
      // The overlay will show when the trigger is hovered with mouse or focus with keyboard.
      return {
        onMouseEnter: handleMouseEnter,
        onMouseLeave: hideOnLeave ? handleMouseLeave : undefined,
        onFocus: handleFocus,
        onBlur: hideOnLeave ? handleBlur : undefined
      };

    default:
      return {};
  }
}